import * as iam from '@aws-cdk/aws-iam';
import { Resource, IResource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { State } from './state';
/**
 * (experimental) Represents an AWS IoT Events detector model.
 *
 * @experimental
 */
export interface IDetectorModel extends IResource {
    /**
     * (experimental) The name of the detector model.
     *
     * @experimental
     * @attribute true
     */
    readonly detectorModelName: string;
}
/**
 * (experimental) Properties for defining an AWS IoT Events detector model.
 *
 * @experimental
 */
export interface DetectorModelProps {
    /**
     * (experimental) The name of the detector model.
     *
     * @default - CloudFormation will generate a unique name of the detector model
     * @experimental
     */
    readonly detectorModelName?: string;
    /**
     * (experimental) The state that is entered at the creation of each detector.
     *
     * @experimental
     */
    readonly initialState: State;
    /**
     * (experimental) The role that grants permission to AWS IoT Events to perform its operations.
     *
     * @default - a role will be created with default permissions
     * @experimental
     */
    readonly role?: iam.IRole;
}
/**
 * (experimental) Defines an AWS IoT Events detector model in this stack.
 *
 * @experimental
 */
export declare class DetectorModel extends Resource implements IDetectorModel {
    /**
     * (experimental) Import an existing detector model.
     *
     * @experimental
     */
    static fromDetectorModelName(scope: Construct, id: string, detectorModelName: string): IDetectorModel;
    /**
     * (experimental) The name of the detector model.
     *
     * @experimental
     */
    readonly detectorModelName: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: DetectorModelProps);
}
